@@ -1,10 +1,6 @@
 from .grids import Grid2D, Grid2DSparse, Grid2DTransformed, Grid2DTransformedNumpy
 from .iterate import Grid2DIterate
 from .interpolate import Grid2DInterpolate
-from .irregular import (
-    Grid2DIrregular,
-    Grid2DIrregularGrouped,
-    Grid2DIrregularGroupedUniform,
-)
+from .irregular import Grid2DIrregular, Grid2DIrregularUniform
 from .pixelization import Grid2DRectangular, Grid2DVoronoi
 from .decorators import *
