@@ -3,7 +3,6 @@ from functools import wraps
 
 from autoconf import conf
 from autoarray.structures import grids
-from autoarray.structures.grids.irregular import AbstractGrid2DIrregular
 
 
 def grid_like_to_structure(func):
@@ -27,24 +26,24 @@ def grid_like_to_structure(func):
     @wraps(func)
     def wrapper(profile, grid, *args, **kwargs):
         """This decorator homogenizes the input of a "grid_like" structure (`Grid2D`, `Grid2DIterate`, `Grid2DInterpolate`
-        or  `Grid2DIrregularGrouped`) into a function. It allows these classes to be interchangeably input into a function,
+        or  `Grid2DIrregular`) into a function. It allows these classes to be interchangeably input into a function,
         such that the grid is used to evalaute the function as every (y,x) coordinates of the grid.
 
-        The grid_like objects `Grid2D` and `Grid2DIrregularGrouped` are input into the function as a flattened 2D NumPy array
+        The grid_like objects `Grid2D` and `Grid2DIrregular` are input into the function as a flattened 2D NumPy array
         of shape [total_coordinates, 2] where second dimension stores the (y,x) values. If a `Grid2DIterate` is input,
         the function is evaluated using the appropriate iterated_*_from_func* function.
 
-        The outputs of the function are converted from a 1D or 2D NumPy Array2D to an *Array2D*, `Grid2D`, *ValuesIrregularGrouped* or
-        `Grid2DIrregularGrouped` objects, whichever is applicable as follows:
+        The outputs of the function are converted from a 1D or 2D NumPy Array2D to an *Array2D*, `Grid2D`, *ValuesIrregular* or
+        `Grid2DIrregular` objects, whichever is applicable as follows:
 
         - If the function returns (y,x) coordinates at every input point, the returned results are returned as a
-         `Grid2D` or `Grid2DIrregularGrouped` structure - the same structure as the input.
+         `Grid2D` or `Grid2DIrregular` structure - the same structure as the input.
 
         - If the function returns scalar values at every input point and a `Grid2D` is input, the returned results are
           an *Array2D* structure which uses the same dimensions and mask as the `Grid2D`.
 
-        - If the function returns scalar values at every input point and `Grid2DIrregularGrouped` are input, the returned
-          results are a *ValuesIrregularGrouped* object with structure resembling that of the `Grid2DIrregularGrouped`..
+        - If the function returns scalar values at every input point and `Grid2DIrregular` are input, the returned
+          results are a *ValuesIrregular* object with structure resembling that of the `Grid2DIrregular`..
 
         If the input array is not a `Grid2D` structure (e.g. it is a 2D NumPy array) the output is a NumPy array.
 
@@ -52,7 +51,7 @@ def grid_like_to_structure(func):
         ----------
         profile : Profile
             A Profile object which uses grid_like inputs to compute quantities at every coordinate on the grid.
-        grid : Grid2D or Grid2DIrregularGrouped
+        grid : Grid2D or Grid2DIrregular
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
 
         Returns
@@ -64,14 +63,14 @@ def grid_like_to_structure(func):
             return grid.iterated_result_from_func(func=func, cls=profile)
         elif isinstance(grid, grids.Grid2DInterpolate):
             return grid.result_from_func(func=func, cls=profile)
-        elif isinstance(grid, AbstractGrid2DIrregular):
+        elif isinstance(grid, grids.Grid2DIrregular):
             result = func(profile, grid, *args, **kwargs)
             return grid.structure_from_result(result=result)
         elif isinstance(grid, grids.Grid2D):
             result = func(profile, grid, *args, **kwargs)
             return grid.structure_from_result(result=result)
 
-        if not isinstance(grid, AbstractGrid2DIrregular) and not isinstance(
+        if not isinstance(grid, grids.Grid2DIrregular) and not isinstance(
             grid, grids.Grid2D
         ):
             return func(profile, grid, *args, **kwargs)
@@ -100,24 +99,24 @@ def grid_like_to_structure_list(func):
     @wraps(func)
     def wrapper(profile, grid, *args, **kwargs):
         """This decorator homogenizes the input of a "grid_like" structure (`Grid2D`, `Grid2DIterate`, `Grid2DInterpolate`
-        or  `Grid2DIrregularGrouped`) into a function. It allows these classes to be interchangeably input into a function,
+        or  `Grid2DIrregular`) into a function. It allows these classes to be interchangeably input into a function,
         such that the grid is used to evalaute the function as every (y,x) coordinates of the grid.
 
-        The grid_like objects `Grid2D` and `Grid2DIrregularGrouped` are input into the function as a flattened 2D NumPy array
+        The grid_like objects `Grid2D` and `Grid2DIrregular` are input into the function as a flattened 2D NumPy array
         of shape [total_coordinates, 2] where second dimension stores the (y,x) values. If a `Grid2DIterate` is input,
         the function is evaluated using the appropriate iterated_*_from_func* function.
 
         If a `Grid2DIterate` is not input the outputs of the function are converted from a list of 1D or 2D NumPy Arrays
-        to a list of *Array2D*, `Grid2D`,  *ValuesIrregularGrouped* or  `Grid2DIrregularGrouped` objects, whichever is applicable as follows:
+        to a list of *Array2D*, `Grid2D`,  *ValuesIrregular* or  `Grid2DIrregular` objects, whichever is applicable as follows:
 
         - If the function returns (y,x) coordinates at every input point, the returned results are returned as a
-         `Grid2D` or `Grid2DIrregularGrouped` structure - the same structure as the input.
+         `Grid2D` or `Grid2DIrregular` structure - the same structure as the input.
 
         - If the function returns scalar values at every input point and a `Grid2D` is input, the returned results are
           an *Array2D* structure which uses the same dimensions and mask as the `Grid2D`.
 
-        - If the function returns scalar values at every input point and `Grid2DIrregularGrouped` are input, the returned
-          results are a *ValuesIrregularGrouped* object with structure resembling that of the `Grid2DIrregularGrouped`.
+        - If the function returns scalar values at every input point and `Grid2DIrregular` are input, the returned
+          results are a *ValuesIrregular* object with structure resembling that of the `Grid2DIrregular`.
 
         if a `Grid2DIterate` is input, the iterated grid calculation is not applicable. Thus, the highest resolution
         sub_size grid in the `Grid2DIterate` is used instead.
@@ -128,7 +127,7 @@ def grid_like_to_structure_list(func):
         ----------
         profile : Profile
             A Profile object which uses grid_like inputs to compute quantities at every coordinate on the grid.
-        grid : Grid2D or Grid2DIrregularGrouped
+        grid : Grid2D or Grid2DIrregular
             A grid_like object of (y,x) coordinates on which the function values are evaluated.
 
         Returns
@@ -150,15 +149,14 @@ def grid_like_to_structure_list(func):
             return grid.grid.structure_list_from_result_list(result_list=result_list)
         elif isinstance(grid, grids.Grid2DInterpolate):
             return func(profile, grid, *args, **kwargs)
-        #     return grid.structure_list_from_result_list(result_list=result_list)
-        elif isinstance(grid, AbstractGrid2DIrregular):
+        elif isinstance(grid, grids.Grid2DIrregular):
             result_list = func(profile, grid, *args, **kwargs)
             return grid.structure_list_from_result_list(result_list=result_list)
         elif isinstance(grid, grids.Grid2D):
             result_list = func(profile, grid, *args, **kwargs)
             return grid.structure_list_from_result_list(result_list=result_list)
 
-        if not isinstance(grid, AbstractGrid2DIrregular) and not isinstance(
+        if not isinstance(grid, grids.Grid2DIrregular) and not isinstance(
             grid, grids.Grid2D
         ):
             return func(profile, grid, *args, **kwargs)
