@@ -2,11 +2,11 @@ import autoarray as aa
 import autoarray.plot as aplt
 import numpy as np
 
-grid = aa.Grid.uniform(shape_2d=(11, 11), pixel_scales=1.0)
+grid = aa.Grid2D.uniform(shape_native=(11, 11), pixel_scales=1.0)
 
-color_array = np.linspace(start=0.0, stop=1.0, num=grid.shape_1d)
+color_array = np.linspace(start=0.0, stop=1.0, num=grid.shape_slim)
 
-aplt.Grid(
+aplt.Grid2D(
     grid=grid,
     color_array=color_array,
     axis_limits=[-1.5, 1.5, -2.5, 2.5],
@@ -15,7 +15,7 @@ aplt.Grid(
     symmetric_around_centre=False,
 )
 
-aplt.Grid(
+aplt.Grid2D(
     grid=grid,
     color_array=color_array,
     axis_limits=[-1.5, 1.5, -2.5, 2.5],
