@@ -3,8 +3,8 @@ import autoarray.plot as aplt
 import numpy as np
 
 
-grid_7x7 = aa.Grid.uniform(shape_2d=(7, 7), pixel_scales=0.25)
-grid_9 = aa.Grid.manual_1d(
+grid_7x7 = aa.Grid2D.uniform(shape_native=(7, 7), pixel_scales=0.25)
+grid_9 = aa.Grid2D.manual_slim(
     grid=[
         [0.6, -0.3],
         [0.5, -0.8],
@@ -16,15 +16,17 @@ grid_9 = aa.Grid.manual_1d(
         [-1.2, 0.8],
         [-1.5, 0.9],
     ],
-    shape_2d=(3, 3),
+    shape_native=(3, 3),
     pixel_scales=1.0,
 )
-voronoi_grid = aa.GridVoronoi(
+voronoi_grid = aa.Grid2DVoronoi(
     grid=grid_9,
-    nearest_pixelization_1d_index_for_mask_1d_index=np.zeros(
-        shape=grid_7x7.shape_1d, dtype="int"
+    nearest_pixelization_index_for_slim_index=np.zeros(
+        shape=grid_7x7.shape_slim, dtype="int"
     ),
 )
-voronoi_mapper = aa.Mapper(grid=grid_7x7, pixelization_grid=voronoi_grid)
+voronoi_mapper = aa.Mapper(
+    source_grid_slim=grid_7x7, source_pixelization_grid=voronoi_grid
+)
 
 aplt.MapperObj(mapper=voronoi_mapper, include_pixelization_grid=True)
