@@ -152,18 +152,19 @@ class TestImaging:
         assert (imaging_capped.psf.native == np.zeros((3, 3))).all()
 
     def test__from_fits__loads_arrays_and_psf_is_renormalized(self):
+
         imaging = aa.Imaging.from_fits(
             pixel_scales=0.1,
             image_path=path.join(test_data_dir, "3x3_ones.fits"),
             psf_path=path.join(test_data_dir, "3x3_twos.fits"),
             noise_map_path=path.join(test_data_dir, "3x3_threes.fits"),
-            positions_path=path.join(test_data_dir, "positions.dat"),
+            positions_path=path.join(test_data_dir, "positions.json"),
         )
 
         assert (imaging.image.native == np.ones((3, 3))).all()
         assert (imaging.psf.native == (1.0 / 9.0) * np.ones((3, 3))).all()
         assert (imaging.noise_map.native == 3.0 * np.ones((3, 3))).all()
-        assert imaging.positions.in_grouped_list == [[(1.0, 1.0), (2.0, 2.0)]]
+        assert imaging.positions.in_list == [(1.0, 1.0), (2.0, 2.0)]
 
         assert imaging.pixel_scales == (0.1, 0.1)
         assert imaging.psf.mask.pixel_scales == (0.1, 0.1)
