@@ -14,26 +14,26 @@ test_coordinates_dir = "{}/files/coordinates/".format(
 class TestObj:
     def test__grid_from_deflection_grid(self):
 
-        grid = aa.GridIterate.uniform(
-            shape_2d=(2, 2),
+        grid = aa.Grid2DIterate.uniform(
+            shape_native=(2, 2),
             pixel_scales=2.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3],
-            store_in_1d=True,
+            store_slim=True,
         )
 
         grid_deflected = grid.grid_from_deflection_grid(deflection_grid=grid)
 
-        assert type(grid_deflected) == grids.GridIterate
+        assert type(grid_deflected) == grids.Grid2DIterate
         assert (
             grid_deflected == np.array([[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]])
         ).all()
         assert (
-            grid_deflected.in_2d
+            grid_deflected.native
             == np.array([[[0.0, 0.0], [0.0, 0.0]], [[0.0, 0.0], [0.0, 0.0]]])
         ).all()
         assert (
-            grid_deflected.in_1d
+            grid_deflected.slim
             == np.array([[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]])
         ).all()
         assert (grid_deflected.mask == grid.mask).all()
@@ -41,29 +41,29 @@ class TestObj:
         assert grid_deflected.origin == (0.0, 0.0)
         assert grid_deflected.fractional_accuracy == 0.1
         assert grid_deflected.sub_steps == [2, 3]
-        assert grid.store_in_1d == True
+        assert grid.store_slim == True
 
-        grid = aa.GridIterate.uniform(
-            shape_2d=(2, 2),
+        grid = aa.Grid2DIterate.uniform(
+            shape_native=(2, 2),
             pixel_scales=2.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3],
-            store_in_1d=False,
+            store_slim=False,
         )
 
         grid_deflected = grid.grid_from_deflection_grid(deflection_grid=grid)
 
-        assert type(grid_deflected) == grids.GridIterate
+        assert type(grid_deflected) == grids.Grid2DIterate
         assert (
             grid_deflected
             == np.array([[[0.0, 0.0], [0.0, 0.0]], [[0.0, 0.0], [0.0, 0.0]]])
         ).all()
         assert (
-            grid_deflected.in_2d
+            grid_deflected.native
             == np.array([[[0.0, 0.0], [0.0, 0.0]], [[0.0, 0.0], [0.0, 0.0]]])
         ).all()
         assert (
-            grid_deflected.in_1d
+            grid_deflected.slim
             == np.array([[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]])
         ).all()
         assert (grid_deflected.mask == grid.mask).all()
@@ -71,7 +71,7 @@ class TestObj:
         assert grid_deflected.origin == (0.0, 0.0)
         assert grid_deflected.fractional_accuracy == 0.1
         assert grid_deflected.sub_steps == [2, 3]
-        assert grid.store_in_1d == False
+        assert grid.store_slim == False
 
     def test__blurring_grid_from_mask__compare_to_array_util(self):
         mask = np.array(
@@ -90,19 +90,19 @@ class TestObj:
 
         mask = aa.Mask2D.manual(mask=mask, pixel_scales=(2.0, 2.0), sub_size=2)
 
-        blurring_mask_util = aa.util.mask.blurring_mask_from(
-            mask=mask, kernel_shape_2d=(3, 5)
+        blurring_mask_util = aa.util.mask.blurring_mask_2d_from(
+            mask_2d=mask, kernel_shape_native=(3, 5)
         )
 
-        blurring_grid_util = aa.util.grid.grid_1d_via_mask_from(
-            mask=blurring_mask_util, pixel_scales=(2.0, 2.0), sub_size=1
+        blurring_grid_util = aa.util.grid.grid_2d_slim_via_mask_from(
+            mask_2d=blurring_mask_util, pixel_scales=(2.0, 2.0), sub_size=1
         )
 
-        grid = aa.GridIterate.from_mask(mask=mask)
+        grid = aa.Grid2DIterate.from_mask(mask=mask)
 
-        blurring_grid = grid.blurring_grid_from_kernel_shape(kernel_shape_2d=(3, 5))
+        blurring_grid = grid.blurring_grid_from_kernel_shape(kernel_shape_native=(3, 5))
 
-        assert isinstance(blurring_grid, grids.GridIterate)
+        assert isinstance(blurring_grid, grids.Grid2DIterate)
         assert len(blurring_grid.shape) == 2
         assert blurring_grid == pytest.approx(blurring_grid_util, 1e-4)
         assert blurring_grid.pixel_scales == (2.0, 2.0)
@@ -124,46 +124,49 @@ class TestObj:
 
         mask = aa.Mask2D.manual(mask=mask, pixel_scales=(2.0, 2.0))
 
-        blurring_mask_util = aa.util.mask.blurring_mask_from(
-            mask=mask, kernel_shape_2d=(3, 5)
+        blurring_mask_util = aa.util.mask.blurring_mask_2d_from(
+            mask_2d=mask, kernel_shape_native=(3, 5)
         )
 
-        blurring_grid_util = aa.util.grid.grid_1d_via_mask_from(
-            mask=blurring_mask_util, pixel_scales=(2.0, 2.0), sub_size=1
+        blurring_grid_util = aa.util.grid.grid_2d_slim_via_mask_from(
+            mask_2d=blurring_mask_util, pixel_scales=(2.0, 2.0), sub_size=1
         )
 
         mask = aa.Mask2D.manual(mask=mask, pixel_scales=(2.0, 2.0))
 
-        blurring_grid = grids.GridIterate.blurring_grid_from_mask_and_kernel_shape(
-            mask=mask, kernel_shape_2d=(3, 5)
+        blurring_grid = grids.Grid2DIterate.blurring_grid_from_mask_and_kernel_shape(
+            mask=mask, kernel_shape_native=(3, 5)
         )
 
-        assert isinstance(blurring_grid, grids.GridIterate)
+        assert isinstance(blurring_grid, grids.Grid2DIterate)
         assert len(blurring_grid.shape) == 2
         assert blurring_grid == pytest.approx(blurring_grid_util, 1e-4)
         assert blurring_grid.pixel_scales == (2.0, 2.0)
 
-        blurring_grid = grids.GridIterate.blurring_grid_from_mask_and_kernel_shape(
-            mask=mask, kernel_shape_2d=(3, 5), store_in_1d=False
+        blurring_grid = grids.Grid2DIterate.blurring_grid_from_mask_and_kernel_shape(
+            mask=mask, kernel_shape_native=(3, 5), store_slim=False
         )
 
-        assert isinstance(blurring_grid, grids.GridIterate)
+        assert isinstance(blurring_grid, grids.Grid2DIterate)
         assert len(blurring_grid.shape) == 3
         assert blurring_grid.pixel_scales == (2.0, 2.0)
 
     def test__padded_grid_from_kernel_shape__matches_grid_2d_after_padding(self):
 
-        grid = grids.GridIterate.uniform(
-            shape_2d=(4, 4), pixel_scales=3.0, fractional_accuracy=0.1, sub_steps=[2, 3]
+        grid = grids.Grid2DIterate.uniform(
+            shape_native=(4, 4),
+            pixel_scales=3.0,
+            fractional_accuracy=0.1,
+            sub_steps=[2, 3],
         )
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=(3, 3))
+        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_native=(3, 3))
 
-        padded_grid_util = aa.util.grid.grid_1d_via_mask_from(
-            mask=np.full((6, 6), False), pixel_scales=(3.0, 3.0), sub_size=1
+        padded_grid_util = aa.util.grid.grid_2d_slim_via_mask_from(
+            mask_2d=np.full((6, 6), False), pixel_scales=(3.0, 3.0), sub_size=1
         )
 
-        assert isinstance(padded_grid, grids.GridIterate)
+        assert isinstance(padded_grid, grids.Grid2DIterate)
         assert padded_grid.shape == (36, 2)
         assert (padded_grid.mask == np.full(fill_value=False, shape=(6, 6))).all()
         assert padded_grid.fractional_accuracy == 0.1
@@ -174,14 +177,14 @@ class TestObj:
             mask=np.full((2, 5), False), pixel_scales=(8.0, 8.0), sub_size=1
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.1, sub_steps=[2, 3]
         )
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=(5, 5))
+        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_native=(5, 5))
 
-        padded_grid_util = aa.util.grid.grid_1d_via_mask_from(
-            mask=np.full((6, 9), False), pixel_scales=(8.0, 8.0), sub_size=1
+        padded_grid_util = aa.util.grid.grid_2d_slim_via_mask_from(
+            mask_2d=np.full((6, 9), False), pixel_scales=(8.0, 8.0), sub_size=1
         )
 
         assert padded_grid.shape == (54, 2)
@@ -204,9 +207,9 @@ class TestIteratedArray:
             pixel_scales=(1.0, 1.0),
         )
 
-        grid = aa.GridIterate.from_mask(mask=mask, fractional_accuracy=0.9999)
+        grid = aa.Grid2DIterate.from_mask(mask=mask, fractional_accuracy=0.9999)
 
-        arr = aa.Array.manual_mask(
+        arr = aa.Array2D.manual_mask(
             array=[
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 1.0, 1.0, 0.0],
@@ -217,7 +220,7 @@ class TestIteratedArray:
         )
 
         fractional_mask = grid.fractional_mask_from_arrays(
-            array_lower_sub_2d=arr.in_2d_binned, array_higher_sub_2d=arr.in_2d_binned
+            array_lower_sub_2d=arr.native_binned, array_higher_sub_2d=arr.native_binned
         )
 
         assert (
@@ -232,7 +235,7 @@ class TestIteratedArray:
             )
         ).all()
 
-        result_array_lower_sub = aa.Array.manual_mask(
+        result_array_lower_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 1.0, 1.0, 0.0],
@@ -242,7 +245,7 @@ class TestIteratedArray:
             mask=mask,
         )
 
-        result_array_higher_sub = aa.Array.manual_mask(
+        result_array_higher_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 2.0, 2.0, 0.0],
@@ -253,8 +256,8 @@ class TestIteratedArray:
         )
 
         fractional_mask = grid.fractional_mask_from_arrays(
-            array_lower_sub_2d=result_array_lower_sub.in_2d_binned,
-            array_higher_sub_2d=result_array_higher_sub.in_2d_binned,
+            array_lower_sub_2d=result_array_lower_sub.native_binned,
+            array_higher_sub_2d=result_array_higher_sub.native_binned,
         )
 
         assert (
@@ -269,9 +272,9 @@ class TestIteratedArray:
             )
         ).all()
 
-        grid = aa.GridIterate.from_mask(mask=mask, fractional_accuracy=0.5)
+        grid = aa.Grid2DIterate.from_mask(mask=mask, fractional_accuracy=0.5)
 
-        result_array_lower_sub = aa.Array.manual_mask(
+        result_array_lower_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 1.9, 0.001, 0.0],
@@ -281,7 +284,7 @@ class TestIteratedArray:
             mask=mask,
         )
 
-        result_array_higher_sub = aa.Array.manual_mask(
+        result_array_higher_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 2.0, 2.0, 0.0],
@@ -292,8 +295,8 @@ class TestIteratedArray:
         )
 
         fractional_mask = grid.fractional_mask_from_arrays(
-            array_lower_sub_2d=result_array_lower_sub.in_2d_binned,
-            array_higher_sub_2d=result_array_higher_sub.in_2d_binned,
+            array_lower_sub_2d=result_array_lower_sub.native_binned,
+            array_higher_sub_2d=result_array_higher_sub.native_binned,
         )
 
         assert (
@@ -330,9 +333,9 @@ class TestIteratedArray:
             pixel_scales=(1.0, 1.0),
         )
 
-        grid = aa.GridIterate.from_mask(mask=mask_lower_sub, fractional_accuracy=0.5)
+        grid = aa.Grid2DIterate.from_mask(mask=mask_lower_sub, fractional_accuracy=0.5)
 
-        array_lower_sub = aa.Array.manual_mask(
+        array_lower_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 2.0, 2.0, 0.0],
@@ -342,7 +345,7 @@ class TestIteratedArray:
             mask=mask_lower_sub,
         )
 
-        array_higher_sub = aa.Array.manual_mask(
+        array_higher_sub = aa.Array2D.manual_mask(
             [
                 [0.0, 0.0, 0.0, 0.0],
                 [0.0, 5.0, 5.0, 0.0],
@@ -353,8 +356,8 @@ class TestIteratedArray:
         )
 
         fractional_mask = grid.fractional_mask_from_arrays(
-            array_lower_sub_2d=array_lower_sub.in_2d_binned,
-            array_higher_sub_2d=array_higher_sub.in_2d_binned,
+            array_lower_sub_2d=array_lower_sub.native_binned,
+            array_higher_sub_2d=array_higher_sub.native_binned,
         )
 
         assert (
@@ -385,60 +388,60 @@ class TestIteratedArray:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=1.0, sub_steps=[2, 3]
         )
 
         mask_sub_1 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=1)
-        grid_sub_1 = aa.Grid.from_mask(mask=mask_sub_1)
+        grid_sub_1 = aa.Grid2D.from_mask(mask=mask_sub_1)
         values_sub_1 = ndarray_1d_from_grid(grid=grid_sub_1, profile=None)
         values_sub_1 = grid_sub_1.structure_from_result(result=values_sub_1)
 
         values = grid.iterated_array_from_func(
             func=ndarray_1d_from_grid,
             cls=None,
-            array_lower_sub_2d=values_sub_1.in_2d_binned,
+            array_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_3 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=3)
-        grid_sub_3 = aa.Grid.from_mask(mask=mask_sub_3)
+        grid_sub_3 = aa.Grid2D.from_mask(mask=mask_sub_3)
         values_sub_3 = ndarray_1d_from_grid(grid=grid_sub_3, profile=None)
         values_sub_3 = grid_sub_3.structure_from_result(result=values_sub_3)
 
-        assert (values == values_sub_3.in_1d_binned).all()
+        assert (values == values_sub_3.slim_binned).all()
 
         # This test ensures that if the fractional accuracy is met on the last sub_size jump (e.g. 2 doesnt meet it,
         # but 3 does) that the sub_size of 3 is used. There was a bug where the mask was not updated correctly and the
         # iterated array double counted the values.
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.9, sub_steps=[2, 3]
         )
 
         values = grid.iterated_array_from_func(
             func=ndarray_1d_from_grid,
             cls=None,
-            array_lower_sub_2d=values_sub_1.in_2d_binned,
+            array_lower_sub_2d=values_sub_1.native_binned,
         )
 
-        assert (values == values_sub_3.in_1d_binned).all()
+        assert (values == values_sub_3.slim_binned).all()
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.000001, sub_steps=[2, 4, 8, 16, 32]
         )
 
         values = grid.iterated_array_from_func(
             func=ndarray_1d_from_grid,
             cls=None,
-            array_lower_sub_2d=values_sub_1.in_2d_binned,
+            array_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_2 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=2)
-        grid_sub_2 = aa.Grid.from_mask(mask=mask_sub_2)
+        grid_sub_2 = aa.Grid2D.from_mask(mask=mask_sub_2)
         values_sub_2 = ndarray_1d_from_grid(grid=grid_sub_2, profile=None)
         values_sub_2 = grid_sub_2.structure_from_result(result=values_sub_2)
 
-        assert (values == values_sub_2.in_1d_binned).all()
+        assert (values == values_sub_2.slim_binned).all()
 
     def test__iterated_array_from_func__check_values_computed_to_fractional_accuracy(
         self,
@@ -456,36 +459,36 @@ class TestIteratedArray:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.5, sub_steps=[2, 4]
         )
 
         mask_sub_1 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=1)
-        grid_sub_1 = aa.Grid.from_mask(mask=mask_sub_1)
+        grid_sub_1 = aa.Grid2D.from_mask(mask=mask_sub_1)
         values_sub_1 = ndarray_1d_from_grid(grid=grid_sub_1, profile=None)
         values_sub_1 = grid_sub_1.structure_from_result(result=values_sub_1)
 
         values = grid.iterated_array_from_func(
             func=ndarray_1d_from_grid,
             cls=None,
-            array_lower_sub_2d=values_sub_1.in_2d_binned,
+            array_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_2 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=2)
-        grid_sub_2 = aa.Grid.from_mask(mask=mask_sub_2)
+        grid_sub_2 = aa.Grid2D.from_mask(mask=mask_sub_2)
         values_sub_2 = ndarray_1d_from_grid(grid=grid_sub_2, profile=None)
         values_sub_2 = grid_sub_2.structure_from_result(result=values_sub_2)
 
         mask_sub_4 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=4)
-        grid_sub_4 = aa.Grid.from_mask(mask=mask_sub_4)
+        grid_sub_4 = aa.Grid2D.from_mask(mask=mask_sub_4)
         values_sub_4 = ndarray_1d_from_grid(grid=grid_sub_4, profile=None)
         values_sub_4 = grid_sub_4.structure_from_result(result=values_sub_4)
 
-        assert values.in_2d[1, 1] == values_sub_2.in_2d_binned[1, 1]
-        assert values.in_2d[2, 2] != values_sub_2.in_2d_binned[2, 2]
+        assert values.native[1, 1] == values_sub_2.native_binned[1, 1]
+        assert values.native[2, 2] != values_sub_2.native_binned[2, 2]
 
-        assert values.in_2d[1, 1] != values_sub_4.in_2d_binned[1, 1]
-        assert values.in_2d[2, 2] == values_sub_4.in_2d_binned[2, 2]
+        assert values.native[1, 1] != values_sub_4.native_binned[1, 1]
+        assert values.native[2, 2] == values_sub_4.native_binned[2, 2]
 
     def test__func_returns_all_zeros__iteration_terminated(self):
 
@@ -501,11 +504,11 @@ class TestIteratedArray:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=1.0, sub_steps=[2, 3]
         )
 
-        arr = aa.Array.manual_mask(array=np.zeros(9), mask=mask)
+        arr = aa.Array2D.manual_mask(array=np.zeros(9), mask=mask)
 
         values = grid.iterated_array_from_func(
             func=ndarray_1d_from_grid, cls=None, array_lower_sub_2d=arr
@@ -527,9 +530,9 @@ class TestIteratedGrid:
             pixel_scales=(1.0, 1.0),
         )
 
-        iterate = aa.GridIterate.from_mask(mask=mask, fractional_accuracy=0.9999)
+        iterate = aa.Grid2DIterate.from_mask(mask=mask, fractional_accuracy=0.9999)
 
-        grid = aa.Grid.manual_mask(
+        grid = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [1.0, 1.0], [1.0, 1.0], [0.0, 0.0]],
@@ -540,7 +543,7 @@ class TestIteratedGrid:
         )
 
         fractional_mask = iterate.fractional_mask_from_grids(
-            grid_lower_sub_2d=grid.in_2d_binned, grid_higher_sub_2d=grid.in_2d_binned
+            grid_lower_sub_2d=grid.native_binned, grid_higher_sub_2d=grid.native_binned
         )
 
         assert (
@@ -555,7 +558,7 @@ class TestIteratedGrid:
             )
         ).all()
 
-        grid_lower_sub = aa.Grid.manual_mask(
+        grid_lower_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [1.0, 1.0], [1.0, 1.0], [0.0, 0.0]],
@@ -565,7 +568,7 @@ class TestIteratedGrid:
             mask=mask,
         )
 
-        grid_higher_sub = aa.Grid.manual_mask(
+        grid_higher_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [2.0, 2.0], [2.0, 2.0], [0.0, 0.0]],
@@ -576,8 +579,8 @@ class TestIteratedGrid:
         )
 
         fractional_mask = iterate.fractional_mask_from_grids(
-            grid_lower_sub_2d=grid_lower_sub.in_2d_binned,
-            grid_higher_sub_2d=grid_higher_sub.in_2d_binned,
+            grid_lower_sub_2d=grid_lower_sub.native_binned,
+            grid_higher_sub_2d=grid_higher_sub.native_binned,
         )
 
         assert (
@@ -592,9 +595,9 @@ class TestIteratedGrid:
             )
         ).all()
 
-        iterate = aa.GridIterate.from_mask(mask=mask, fractional_accuracy=0.5)
+        iterate = aa.Grid2DIterate.from_mask(mask=mask, fractional_accuracy=0.5)
 
-        grid_lower_sub = aa.Grid.manual_mask(
+        grid_lower_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [1.9, 1.9], [0.001, 0.001], [0.0, 0.0]],
@@ -604,7 +607,7 @@ class TestIteratedGrid:
             mask=mask,
         )
 
-        grid_higher_sub = aa.Grid.manual_mask(
+        grid_higher_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [2.0, 2.0], [2.0, 2.0], [0.0, 0.0]],
@@ -615,8 +618,8 @@ class TestIteratedGrid:
         )
 
         fractional_mask = iterate.fractional_mask_from_grids(
-            grid_lower_sub_2d=grid_lower_sub.in_2d_binned,
-            grid_higher_sub_2d=grid_higher_sub.in_2d_binned,
+            grid_lower_sub_2d=grid_lower_sub.native_binned,
+            grid_higher_sub_2d=grid_higher_sub.native_binned,
         )
 
         assert (
@@ -653,9 +656,11 @@ class TestIteratedGrid:
             pixel_scales=(1.0, 1.0),
         )
 
-        iterate = aa.GridIterate.from_mask(mask=mask_lower_sub, fractional_accuracy=0.5)
+        iterate = aa.Grid2DIterate.from_mask(
+            mask=mask_lower_sub, fractional_accuracy=0.5
+        )
 
-        grid_lower_sub = aa.Grid.manual_mask(
+        grid_lower_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [2.0, 2.0], [2.0, 2.0], [0.0, 0.0]],
@@ -665,7 +670,7 @@ class TestIteratedGrid:
             mask=mask_lower_sub,
         )
 
-        grid_higher_sub = aa.Grid.manual_mask(
+        grid_higher_sub = aa.Grid2D.manual_mask(
             [
                 [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
                 [[0.0, 0.0], [0.1, 2.0], [0.1, 0.1], [0.0, 0.0]],
@@ -676,8 +681,8 @@ class TestIteratedGrid:
         )
 
         fractional_mask = iterate.fractional_mask_from_grids(
-            grid_lower_sub_2d=grid_lower_sub.in_2d_binned,
-            grid_higher_sub_2d=grid_higher_sub.in_2d_binned,
+            grid_lower_sub_2d=grid_lower_sub.native_binned,
+            grid_higher_sub_2d=grid_higher_sub.native_binned,
         )
 
         assert (
@@ -708,60 +713,60 @@ class TestIteratedGrid:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=1.0, sub_steps=[2, 3]
         )
 
         mask_sub_1 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=1)
-        grid_sub_1 = aa.Grid.from_mask(mask=mask_sub_1)
+        grid_sub_1 = aa.Grid2D.from_mask(mask=mask_sub_1)
         values_sub_1 = ndarray_2d_from_grid(grid=grid_sub_1, profile=None)
         values_sub_1 = grid_sub_1.structure_from_result(result=values_sub_1)
 
         values = grid.iterated_grid_from_func(
             func=ndarray_2d_from_grid,
             cls=None,
-            grid_lower_sub_2d=values_sub_1.in_2d_binned,
+            grid_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_3 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=3)
-        grid_sub_3 = aa.Grid.from_mask(mask=mask_sub_3)
+        grid_sub_3 = aa.Grid2D.from_mask(mask=mask_sub_3)
         values_sub_3 = ndarray_2d_from_grid(grid=grid_sub_3, profile=None)
         values_sub_3 = grid_sub_3.structure_from_result(result=values_sub_3)
 
-        assert (values == values_sub_3.in_1d_binned).all()
+        assert (values == values_sub_3.slim_binned).all()
 
         # This test ensures that if the fractional accuracy is met on the last sub_size jump (e.g. 2 doesnt meet it,
         # but 3 does) that the sub_size of 3 is used. There was a bug where the mask was not updated correctly and the
         # iterated grid double counted the values.
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.99, sub_steps=[2, 3]
         )
 
         values = grid.iterated_grid_from_func(
             func=ndarray_2d_from_grid,
             cls=None,
-            grid_lower_sub_2d=values_sub_1.in_2d_binned,
+            grid_lower_sub_2d=values_sub_1.native_binned,
         )
 
-        assert (values == values_sub_3.in_1d_binned).all()
+        assert (values == values_sub_3.slim_binned).all()
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.000001, sub_steps=[2, 4, 8, 16, 32]
         )
 
         values = grid.iterated_grid_from_func(
             func=ndarray_2d_from_grid,
             cls=None,
-            grid_lower_sub_2d=values_sub_1.in_2d_binned,
+            grid_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_2 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=2)
-        grid_sub_2 = aa.Grid.from_mask(mask=mask_sub_2)
+        grid_sub_2 = aa.Grid2D.from_mask(mask=mask_sub_2)
         values_sub_2 = ndarray_2d_from_grid(grid=grid_sub_2, profile=None)
         values_sub_2 = grid_sub_2.structure_from_result(result=values_sub_2)
 
-        assert (values == values_sub_2.in_1d_binned).all()
+        assert (values == values_sub_2.slim_binned).all()
 
     def test__iterated_grid_from_func__check_values_computed_to_fractional_accuracy(
         self,
@@ -779,42 +784,42 @@ class TestIteratedGrid:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=0.5, sub_steps=[2, 4]
         )
 
         mask_sub_1 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=1)
-        grid_sub_1 = aa.Grid.from_mask(mask=mask_sub_1)
+        grid_sub_1 = aa.Grid2D.from_mask(mask=mask_sub_1)
         values_sub_1 = ndarray_2d_from_grid(grid=grid_sub_1, profile=None)
         values_sub_1 = grid_sub_1.structure_from_result(result=values_sub_1)
 
         values = grid.iterated_grid_from_func(
             func=ndarray_2d_from_grid,
             cls=None,
-            grid_lower_sub_2d=values_sub_1.in_2d_binned,
+            grid_lower_sub_2d=values_sub_1.native_binned,
         )
 
         mask_sub_2 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=2)
-        grid_sub_2 = aa.Grid.from_mask(mask=mask_sub_2)
+        grid_sub_2 = aa.Grid2D.from_mask(mask=mask_sub_2)
         values_sub_2 = ndarray_2d_from_grid(grid=grid_sub_2, profile=None)
         values_sub_2 = grid_sub_2.structure_from_result(result=values_sub_2)
 
         mask_sub_4 = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=4)
-        grid_sub_4 = aa.Grid.from_mask(mask=mask_sub_4)
+        grid_sub_4 = aa.Grid2D.from_mask(mask=mask_sub_4)
         values_sub_4 = ndarray_2d_from_grid(grid=grid_sub_4, profile=None)
         values_sub_4 = grid_sub_4.structure_from_result(result=values_sub_4)
 
-        assert values.in_2d[1, 1, 0] == values_sub_2.in_2d_binned[1, 1, 0]
-        assert values.in_2d[2, 2, 0] != values_sub_2.in_2d_binned[2, 2, 0]
+        assert values.native[1, 1, 0] == values_sub_2.native_binned[1, 1, 0]
+        assert values.native[2, 2, 0] != values_sub_2.native_binned[2, 2, 0]
 
-        assert values.in_2d[1, 1, 0] != values_sub_4.in_2d_binned[1, 1, 0]
-        assert values.in_2d[2, 2, 0] == values_sub_4.in_2d_binned[2, 2, 0]
+        assert values.native[1, 1, 0] != values_sub_4.native_binned[1, 1, 0]
+        assert values.native[2, 2, 0] == values_sub_4.native_binned[2, 2, 0]
 
-        assert values.in_2d[1, 1, 1] == values_sub_2.in_2d_binned[1, 1, 1]
-        assert values.in_2d[2, 2, 1] != values_sub_2.in_2d_binned[2, 2, 1]
+        assert values.native[1, 1, 1] == values_sub_2.native_binned[1, 1, 1]
+        assert values.native[2, 2, 1] != values_sub_2.native_binned[2, 2, 1]
 
-        assert values.in_2d[1, 1, 1] != values_sub_4.in_2d_binned[1, 1, 1]
-        assert values.in_2d[2, 2, 1] == values_sub_4.in_2d_binned[2, 2, 1]
+        assert values.native[1, 1, 1] != values_sub_4.native_binned[1, 1, 1]
+        assert values.native[2, 2, 1] == values_sub_4.native_binned[2, 2, 1]
 
     def test__func_returns_all_zeros__iteration_terminated(self):
 
@@ -830,11 +835,11 @@ class TestIteratedGrid:
             origin=(0.001, 0.001),
         )
 
-        grid = aa.GridIterate.from_mask(
+        grid = aa.Grid2DIterate.from_mask(
             mask=mask, fractional_accuracy=1.0, sub_steps=[2, 3]
         )
 
-        grid_lower = aa.Grid.manual_mask(grid=np.zeros((9, 2)), mask=mask)
+        grid_lower = aa.Grid2D.manual_mask(grid=np.zeros((9, 2)), mask=mask)
 
         values = grid.iterated_grid_from_func(
             func=ndarray_1d_from_grid, cls=None, grid_lower_sub_2d=grid_lower
@@ -844,56 +849,58 @@ class TestIteratedGrid:
 
 
 class TestAPI:
-    def test__manual_1d(self):
+    def test__manual_slim(self):
 
-        grid = aa.GridIterate.manual_1d(
+        grid = aa.Grid2DIterate.manual_slim(
             grid=[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]],
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=1.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3, 4],
             origin=(0.0, 1.0),
-            store_in_1d=True,
+            store_slim=True,
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert (
             grid == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]])
         ).all()
         assert (
-            grid.in_2d == np.array([[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]])
+            grid.native
+            == np.array([[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]])
         ).all()
         assert (
-            grid.in_1d == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]])
+            grid.slim == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]])
         ).all()
         assert grid.pixel_scales == (1.0, 1.0)
         assert grid.fractional_accuracy == 0.1
         assert grid.sub_steps == [2, 3, 4]
         assert grid.origin == (0.0, 1.0)
 
-        grid = aa.GridIterate.manual_1d(
+        grid = aa.Grid2DIterate.manual_slim(
             grid=[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]],
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=1.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3, 4],
             origin=(0.0, 1.0),
-            store_in_1d=False,
+            store_slim=False,
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert (
             grid == np.array([[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]])
         ).all()
         assert (
-            grid.in_2d == np.array([[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]])
+            grid.native
+            == np.array([[[1.0, 2.0], [3.0, 4.0]], [[5.0, 6.0], [7.0, 8.0]]])
         ).all()
         assert (
-            grid.in_1d == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]])
+            grid.slim == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [7.0, 8.0]])
         ).all()
         assert grid.pixel_scales == (1.0, 1.0)
         assert grid.fractional_accuracy == 0.1
@@ -911,33 +918,33 @@ class TestAPI:
         )
         mask = aa.Mask2D.manual(mask=mask, pixel_scales=(2.0, 2.0), sub_size=2)
 
-        grid_via_util = aa.util.grid.grid_1d_via_mask_from(
-            mask=mask, sub_size=1, pixel_scales=(2.0, 2.0)
+        grid_via_util = aa.util.grid.grid_2d_slim_via_mask_from(
+            mask_2d=mask, sub_size=1, pixel_scales=(2.0, 2.0)
         )
 
-        grid = aa.GridIterate.from_mask(
-            mask=mask, fractional_accuracy=0.1, sub_steps=[2, 3, 4], store_in_1d=True
+        grid = aa.Grid2DIterate.from_mask(
+            mask=mask, fractional_accuracy=0.1, sub_steps=[2, 3, 4], store_slim=True
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert grid == pytest.approx(grid_via_util, 1e-4)
         assert grid.pixel_scales == (2.0, 2.0)
         assert grid.sub_steps == [2, 3, 4]
         assert grid.sub_size == 1
 
         grid_via_util = aa.util.grid.grid_2d_via_mask_from(
-            mask=mask, sub_size=1, pixel_scales=(2.0, 2.0)
+            mask_2d=mask, sub_size=1, pixel_scales=(2.0, 2.0)
         )
 
-        grid = aa.GridIterate.from_mask(
-            mask=mask, fractional_accuracy=0.1, sub_steps=[2, 3, 4], store_in_1d=False
+        grid = aa.Grid2DIterate.from_mask(
+            mask=mask, fractional_accuracy=0.1, sub_steps=[2, 3, 4], store_slim=False
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert grid == pytest.approx(grid_via_util, 1e-4)
         assert grid.pixel_scales == (2.0, 2.0)
         assert grid.sub_steps == [2, 3, 4]
@@ -945,52 +952,52 @@ class TestAPI:
 
     def test__uniform(self):
 
-        grid = aa.GridIterate.uniform(
-            shape_2d=(2, 2),
+        grid = aa.Grid2DIterate.uniform(
+            shape_native=(2, 2),
             pixel_scales=2.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3, 4],
-            store_in_1d=True,
+            store_slim=True,
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert (
             grid == np.array([[1.0, -1.0], [1.0, 1.0], [-1.0, -1.0], [-1.0, 1.0]])
         ).all()
         assert (
-            grid.in_2d
+            grid.native
             == np.array([[[1.0, -1.0], [1.0, 1.0]], [[-1.0, -1.0], [-1.0, 1.0]]])
         ).all()
         assert (
-            grid.in_1d == np.array([[1.0, -1.0], [1.0, 1.0], [-1.0, -1.0], [-1.0, 1.0]])
+            grid.slim == np.array([[1.0, -1.0], [1.0, 1.0], [-1.0, -1.0], [-1.0, 1.0]])
         ).all()
         assert grid.pixel_scales == (2.0, 2.0)
         assert grid.fractional_accuracy == 0.1
         assert grid.sub_steps == [2, 3, 4]
         assert grid.origin == (0.0, 0.0)
 
-        grid = aa.GridIterate.uniform(
-            shape_2d=(2, 2),
+        grid = aa.Grid2DIterate.uniform(
+            shape_native=(2, 2),
             pixel_scales=2.0,
             fractional_accuracy=0.1,
             sub_steps=[2, 3, 4],
-            store_in_1d=False,
+            store_slim=False,
         )
 
-        assert type(grid) == grids.GridIterate
-        assert type(grid.in_1d) == grids.GridIterate
-        assert type(grid.in_2d) == grids.GridIterate
+        assert type(grid) == grids.Grid2DIterate
+        assert type(grid.slim) == grids.Grid2DIterate
+        assert type(grid.native) == grids.Grid2DIterate
         assert (
             grid == np.array([[[1.0, -1.0], [1.0, 1.0]], [[-1.0, -1.0], [-1.0, 1.0]]])
         ).all()
         assert (
-            grid.in_2d
+            grid.native
             == np.array([[[1.0, -1.0], [1.0, 1.0]], [[-1.0, -1.0], [-1.0, 1.0]]])
         ).all()
         assert (
-            grid.in_1d == np.array([[1.0, -1.0], [1.0, 1.0], [-1.0, -1.0], [-1.0, 1.0]])
+            grid.slim == np.array([[1.0, -1.0], [1.0, 1.0], [-1.0, -1.0], [-1.0, 1.0]])
         ).all()
         assert grid.pixel_scales == (2.0, 2.0)
         assert grid.fractional_accuracy == 0.1
