@@ -22,6 +22,7 @@ class TestVisibilitiesAPI:
         assert type(visibilities) == vis.Visibilities
         assert (visibilities.slim == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
         assert (visibilities.in_array == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
+        assert (visibilities.ordered_1d == np.array([1.0, 3.0, 2.0, 4.0])).all()
         assert (visibilities.amplitudes == np.array([np.sqrt(5), 5.0])).all()
         assert visibilities.phases == pytest.approx(
             np.array([1.10714872, 0.92729522]), 1.0e-4
@@ -38,6 +39,9 @@ class TestVisibilitiesAPI:
         assert (
             visibilities.in_array == np.array([[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]])
         ).all()
+        assert (
+            visibilities.ordered_1d == np.array([1.0, 3.0, 5.0, 2.0, 4.0, 6.0])
+        ).all()
 
     def test__manual__makes_visibilities_with_converted_input_as_list(self):
 
@@ -147,29 +151,7 @@ class TestVisibilitiesNoiseMap:
         assert noise_map.phases == pytest.approx(
             np.array([1.10714872, 0.92729522]), 1.0e-4
         )
-
-        noise_map = aa.VisibilitiesNoiseMap.manual_slim(
-            visibilities=[[1.0, 1.0], [2.0, 2.0], [2.0, 4.0]]
-        )
-
+        assert (noise_map.ordered_1d == np.array([1.0, 3.0, 2.0, 4.0])).all()
         assert (
-            noise_map.Wop.todense()
-            == np.array(
-                [
-                    [1.0 + 0.0j, 0.0 + 0.0j, 0.0 + 0.0j],
-                    [0.0 + 0.0j, 0.5 + 0.0j, 0.0 + 0.0j],
-                    [0.0 + 0.0j, 0.0 + 0.0j, 0.5 + 0.0j],
-                ]
-            )
+            noise_map.weights_ordered_1d == np.array([1.0, 1.0 / 9.0, 0.25, 0.0625])
         ).all()
-
-        # assert (
-        #     noise_map.Wop.todense()
-        #     == np.array(
-        #         [
-        #             [1.0 + 1.0j, 0.0 + 0.0j, 0.0 + 0.0j],
-        #             [0.0 + 0.0j, 0.5 + 0.5j, 0.0 + 0.0j],
-        #             [0.0 + 0.0j, 0.0 + 0.0j, 0.5 + 0.25j],
-        #         ]
-        #     )
-        # ).all()
